{% extends "admin/change_form.html" %}  {# Unfold’s base via Unfold #}
{% load admin_modify %}

{# ensure submit buttons exist #}
{% block submit_buttons_top %}{% submit_row %}{% endblock %}
{% block submit_buttons_bottom %}{% submit_row %}{% endblock %}