{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_list cms_admin admin_modify unfold %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} change-list{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
  <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
  &rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
  &rsaquo; {{ opts.verbose_name_plural|capfirst }}
</div>
{% endblock %}
{% endif %}

{% block extrahead %}{{ block.super }}{{ form.media }}{% endblock %}

{% block content %}
  <div id="content-main">
    <div class="module" id="changelist">
        <form action="{% url opts|admin_urlname:"changelist" %}">
            <fieldset class="module aligned">
                <div class="form-row">
                    <div class="flex-container">
                        {{ form }}
                    </div>
                </div>
            </fieldset>
            <button class="djangocms-versioning submit" type="submit">{% translate "Submit" %}</button>
        </form>
    </div>
</div>
{% endblock %}