{% extends "admin/change_form.html" %}
{% load i18n cms_admin cms_static %}

{% block extrahead %}
    {# in case plugins require widgets, they need to have bundle here #}
    <script src="{% static_with_version "cms/js/dist/bundle.admin.base.min.js" %}" type="text/javascript"></script>
    {{ block.super }}
{% endblock %}

{% block form_top %}
    {# Unfold separates form and submit-row - Re‐insert the plugin submit‐row so it’s still inside <form> #}
    {{ block.super }}

    {% block submit_buttons_bottom %}
        {% submit_row_plugin %}
    {% endblock %}
{% endblock %}